Index: src/snapshot.h |
diff --git a/src/snapshot.h b/src/snapshot.h |
index b785cf57008999f622b1d466314e9239a76a2f67..3d752a72aa745f1f57a2aaee6d637645617743bf 100644 |
--- a/src/snapshot.h |
+++ b/src/snapshot.h |
@@ -12,9 +12,9 @@ namespace internal { |
class Snapshot { |
public: |
- // Initialize the VM from the internal snapshot. Returns false if no snapshot |
- // could be found. |
- static bool Initialize(); |
+ // Initialize the Isolate from the internal snapshot. Returns false if no |
+ // snapshot could be found. |
+ static bool Initialize(Isolate* isolate); |
static bool HaveASnapshotToStartFrom(); |